@@ -38,7 +38,7 @@ class CustomGS extends CMSModule
 	
 	function GetVersion()
 	{
-		return '1.2';
+		return '1.3';
 	}
 	
 	function MinimumCMSVersion()
@@ -88,7 +88,7 @@ class CustomGS extends CMSModule
 
 	function VisibleToAdminUser() 
 	{
-		return $this->CheckPermission('Custom Global Settings - Manage' || 'Custom Global Settings - Use');
+		return $this->CheckPermission('Custom Global Settings - Manage') || $this->CheckPermission('Custom Global Settings - Use');
 	}
 
 	function GetDependencies()
@@ -99,9 +99,9 @@ class CustomGS extends CMSModule
 	function SetParameters()
 	{
 		$this->RegisterModulePlugin();
-	  $this->RestrictUnknownParams();
-		$this->CreateParameter('showvars','1','Set this parameter to show all available variables and their values. For testing purposes only.');
-	  $this->SetParameterType('showvars',CLEAN_STRING);
+		$this->RestrictUnknownParams();
+		$this->CreateParameter('showvars',1,'Set this parameter to show all available variables and their values. For testing purposes only.');
+		$this->SetParameterType('showvars',CLEAN_INT);
 	}
 	
   function GetEventDescription($eventname)
@@ -179,7 +179,7 @@ EOT;
 	* @access public
 	* @return array()
 	*/
-	function GetSettings()
+	function GetSettings($parseSmarty = true)
 	{
 		$fields = array();
 
@@ -191,7 +191,7 @@ EOT;
 			while ( $row=$result->FetchRow() )
 			{
 				$alias = str_replace('__', '_', str_replace('-', '_', munge_string_to_url($row['name'])));
-				if ( ($row['type'] == 'textarea' || $row['type'] == 'wysiwyg') && $row['properties'] )
+				if ( $parseSmarty && ($row['type'] == 'textarea' || $row['type'] == 'wysiwyg') && $row['properties'] )
 				{
 					$fields[$alias] = $this->ProcessTemplateFromData($row['value']);
 				}
@@ -206,17 +206,17 @@ EOT;
 	}
 
 	/**
-	* Method to clear the site cache
+	* Method to clear the combined stylesheet cache
 	*
 	* @final
 	* @access private
 	* @return void
 	*/
-	function ClearCache()
+	function ClearStylesheetCache()
 	{
-		$gCms = cmsms();
-		$contentops = $gCms->GetContentOperations();
-		$contentops->ClearCache();
+		foreach (glob("../tmp/cache/stylesheet_combined_*.css") as $filename) {
+			@unlink($filename);
+		}
 	}
 
 }
