@@ -27,7 +27,7 @@ if (!isset($gCms)) exit;
 if( !$this->CheckPermission('Custom Global Settings - Manage') ) $this->Redirect($id, "defaultadmin", $returnid);
 
 // Get all fields and settings
-$allfields = $this->GetSettings();
+$allfields = $this->GetSettings(false);
 $clearcache = 0;
 
 foreach( $allfields as $key => $value )
@@ -49,15 +49,16 @@ foreach( $allfields as $key => $value )
 						'fieldid' => $field['fieldid'],
 						'name' => $field['name'],
 						'alias' => str_replace('__', '_', str_replace('-', '_', munge_string_to_url($field['name']))),
-						'value' => $newvalue
+						'value' => $newvalue,
+						'clearcache' => $field['clearcache']
 			));
 			$clearcache = $clearcache || $field['clearcache'];
 		}
 	}
 }
 
-// Clear the site cache if required by one of the fields and only if that field has been changed
-if ( $clearcache ) $this->ClearCache();
+// Clear the stylesheet cache if required by one of the fields and only if that field has been changed
+if ( $clearcache ) $this->ClearStylesheetCache();
 
 // Show saved parameters in debug mode
 debug_display($params);
