@@ -61,8 +61,10 @@ if ( $result && $result->RecordCount() > 0 )
 			case 'radiobuttons':
 				// lets parse this by smarty first
 				$row['properties'] = $this->ProcessTemplateFromData($row['properties']);
+				$row['properties'] = preg_replace('#<!--(.+)-->#is', '', $row['properties']); // filter out html comments
 				$row['properties'] = str_replace("\r", "\n", $row['properties']);
 				$row['properties'] = str_replace("\n\n", "\n", $row['properties']);
+				$row['properties'] = trim($row['properties']);
 				$properties = explode("\n", $row['properties']);
 				$items = array();
 				foreach ($properties as $property)
@@ -119,44 +121,51 @@ $smarty->assign('cancel',$this->CreateInputSubmit ($id, 'cancel', lang('cancel')
 $smarty->assign('startform', $this->CreateFormStart( $id, 'save_general', $returnid ));
 $smarty->assign('endform', $this->CreateFormEnd());
 
-$strTime=mktime(1,1,1,2,1,2000);
-$feb = date("F",$strTime);
+if ( function_exists('cms_admin_current_language') ) setlocale(LC_TIME, cms_admin_current_language()); // for cmsms 1.10 only
+for ($i = 1; $i <= 12; $i++)
+{
+	$timestamp=mktime(1,1,1,$i,1,2000);
+	$months[] = htmlentities(strftime('%B', $timestamp));
+}
+$monthnames = implode("','",$months);
+for ($i = 1; $i <= 7; $i++)
+{
+	$timestamp=mktime(1,1,1,10,$i,2000);
+	$days[] = htmlentities(strftime('%A', $timestamp));
+	$daysmin[] = htmlentities(substr(strftime('%a', $timestamp), 0, 2));
+}
+$daynames = implode("','",$days);
+$daynamesmin = implode("','",$daysmin);
 
 $DP_locale = "
-	$.datepicker.regional['nl'] = {
-		closeText: 'sluit',
-		prevText: '<vorige',
-		nextText: 'volgende>',
-		currentText: 'nu',
-		monthNames: ['januari','".$feb."','maart','april','mei','juni',
-		'juli','augustus','september','oktober','november','december'],
+	$.datepicker.regional[''] = {
+		closeText: '" . lang('close') . "',
+		prevText: '" . lang('previous') . "',
+		nextText: '" . lang('next') . "',
+		currentText: '" . $this->Lang('now') . "',
+		monthNames: ['" . $monthnames . "'],
+		dayNames: ['" . $daynames . "'],
+		dayNamesMin: ['" . $daynamesmin . "'],
 		dateFormat: 'yyyy-mm-dd',
 		firstDay: 1,
 		isRTL: false,
 		showMonthAfterYear: false,
 		yearSuffix: ''
 	};
-	$.datepicker.setDefaults($.datepicker.regional['nl']);
+	$.datepicker.setDefaults($.datepicker.regional['']);
 
-	$.timepicker.regional['nl'] = {
-		timeOnlyTitle: 'Kies tijd',
-		timeText: 'tijd',
-		hourText: 'uur',
-		minuteText: 'minuten',
-		currentText: 'nu',
-		closeText: 'sluit',
+	$.timepicker.regional[''] = {
+		timeOnlyTitle: '" . $this->Lang('choosetime') . "',
+		timeText: '" . $this->Lang('time') . "',
+		hourText: '" . lang('hour') . "',
+		minuteText: '" . lang('minutes') . "',
+		currentText: '" . $this->Lang('now') . "',
+		closeText: '" . lang('close') . "',
 		ampm: false
 	};
-	$.timepicker.setDefaults($.timepicker.regional['nl']);	
+	$.timepicker.setDefaults($.timepicker.regional['']);
 ";
 
-for ($i = 1; $i <= 12; $i++)
-{
-	
-}
-	
-
-		
 $smarty->assign('DP_locale', $DP_locale);
 
 
